@@ -31,9 +31,7 @@ struct _sstr {
 	int growable;
 };
 
-int grow(sstr * p, int size);
-int shrink(sstr * p);
+int sstr_alloc_space(sstr *p, int len);
 void (*on_error) (void);
 
 #endif /*SSTR_PRIVATE_H*/
-
