@@ -28,12 +28,13 @@
 
 void ftpcmds_init(void);
 
-typedef struct _cmd_struct {
+struct cmd_struct {
 	char name[5];
 	void (*cmd) (sstr * cmd, sstr * arg);
-} cmd_struct;
+};
 
-cmd_struct *ftp_cmds;
+struct cmd_struct *ftp_cmds;
+void user_munge(sstr * cmd, sstr * arg);
 
 
 #endif				/* FTP_CMDS_H */
