@@ -8,8 +8,9 @@
 /*****************
 **linux.c/bsd.c **
 ******************/
+int os_init(void);
 int get_orig_dest(int fd, struct sockaddr_in *addr);
-int get_local_address(struct sockaddr_in *addr);
+int get_local_address(const int fd, struct sockaddr_in *addr);
 int bindtodevice(int fd);
 
 #ifdef TRANS_DATA
@@ -17,7 +18,7 @@ struct fd_request {
 	enum {CONNECT, LISTEN, UNLISTEN, NONE} type;
 	struct sockaddr_in local;
 	struct sockaddr_in remote;
-	u_int16_t ports[2];
+	int ports[2];
 };
 
 int kernel_transdata_setup(void);
