@@ -13,6 +13,7 @@ void vscan_new(int sz);
 void vscan_inc(sstr * inc);
 int vscan_switchover(void);
 int vscan_end(void);
+void vscan_abort(void);
 int vscan_parsed_reply(int code, sstr * msg);
 #else
 static inline void vscan_init(void) {};
@@ -20,6 +21,7 @@ static inline void vscan_new(int sz) {};
 static inline void vscan_inc(sstr * inc) {};
 static inline int vscan_switchover(void) {return 0;};
 static inline int vscan_end(void) {return -1;};
+static inline void vscan_abort(void) {};
 static inline int vscan_parsed_reply(int code, sstr * msg) {return 0;};
 #endif
 
